/**************************************************************
            ==================================
            Star Wars - The POV-Ray Collection
            ==================================

TIE_I.INC - 3D model description file for use with the
Persistence of Vision Ray-Tracer, v3.0

POV-Ray code copyright (c) 1997 D M Beattie

This model is provided for personal use only. Any use of this
model for commercial gain or profit is strictly forbidden -
please see the accompanying README.TXT and Conditions of Use
before using or distributing this model.

'Star Wars' and all associated images, designs and trademarks,
(including the designs of the vehicles and objects depicted in
the Star Wars POV-Ray Collection, except where otherwise
stated) are copyright (c) 1997 Lucasfilm Ltd.

**************************************************************/

// TIE_I.INC - TIE Interceptor model definition for POV-Ray v3.0

/*
NOTE: Before rendering this image, render the file TCPMAP.POV
according to the instructions within the file - this model uses
the output from that file as an image map, and will not render
unless the file TCPMAP.TGA is within the search path.
*/

#declare TI_Tex1=texture { //Lighter Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.55,0.55,0.67>]
      [0.5 colour rgb <0.52,0.52,0.66>]
      [1.0 colour rgb <0.53,0.54,0.67>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TI_Tex2=texture { //Medium Gray Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.35,0.39,0.5>]
      [0.5 colour rgb <0.37,0.42,0.52>]
      [1.0 colour rgb <0.32,0.39,0.5>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TI_Tex3=texture { // Dark Grey Sections
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.2,0.25,0.35>]
      [0.5 colour rgb <0.22,0.23,0.31>]
      [1.0 colour rgb <0.23,0.29,0.35>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}

#declare TI_Tex4=texture { // Cockpit frame texture
  pigment {
    bozo
    colour_map {
      [0.0 colour rgb <0.22,0.22,0.23>]
      [0.5 colour rgb <0.25,0.25,0.25>]
      [1.0 colour rgb <0.23,0.25,0.27>]
    }
    scale 0.01
  }
  normal {dents 0.2 scale 0.01}
  finish {ambient 0.1 diffuse 0.8}
}


#declare TI_Screen_Tex = texture {
  pigment {colour rgb 0.01}
  finish {specular 0.5 roughness 0.01 reflection 0.3}
}

#declare TI_SolarPanel = texture { //'Striped' texture on solar panels
  pigment {
    gradient <0,1,0>
    colour_map {
      [0.0 colour rgb <0.2,0.2,0.21>]
      [0.8 colour rgb <0.2,0.2,0.21>]
      [0.8 colour rgb 0.8]
      [1 colour rgb 0.8]
    }
    scale <1,0.05,1>
    translate <0,20,0>
  }
  finish {
    specular 0.3
    roughness 0.01
  }
}

#declare TI_PanelMount = object {
  union {
    object {cone {<0,0,0>, 0.1, <0,0.8,0>, 0.08} scale <8,1,0.1> texture {TI_Tex2}}
    object {cone {<0,0,0>, 0.07, <0,0.6,0>, 0.05} scale <7,1,0.1> texture {TI_Tex3} rotate <0,90,0>}
    object {cylinder {<0,0,0>, <0,0.5,0>, 0.35} texture {TI_Tex3}}
    object {cylinder {<0,0,0>, <0,0.7,0>, 0.3} texture {TI_Tex3}}
    object {cylinder {<0,0,0>, <0,2,0>, 0.25} texture {TI_Tex3}}
    object {cone {<0,1,0>, 0.3, <0,2.5,0>, 0.9} scale <0.01,1,1> texture {TI_Tex2}}
  }
  rotate <0,0,-90>
  rotate <90,0,0>
  scale <-1,1,1>
}

#declare TI_PanelA = object {
  #declare TIA = <0,0,3.5>
  #declare TIB = <0,2,0>
  #declare TIC = <0,2,-1>
  #declare TID = <0,0,-1.6>
  #declare TIE = <0,0,0>
  #declare TIR1 = 0.05
  #declare TIR2 = 0.02
  union {
    object {
      intersection {
        object {
          union {
            object {cylinder {TIA,TIB,TIR1}}
            object {cylinder {TIB,TIC,TIR1}}
            object {cylinder {TIC,TID,TIR1}}
            object {cylinder {TID,TIE,TIR1}}
            object {cylinder {TIE,TIA,TIR1}}
            object {cylinder {TIE,TIB,TIR1}}
            object {sphere {TIA,TIR1}}
            object {sphere {TIB,TIR1}}
            object {sphere {TIC,TIR1}}
            object {sphere {TID,TIR1}}
            object {sphere {TIE,TIR1}}
          }
          scale <5,1,1>
        }
        object {box {<-0.025, -1, -2>, <0.025, 3, 4>}}
      }
      texture {TI_Tex1}
    }
    object {
      intersection {
        object {
          union {
            object {cylinder {TIA,TIB,TIR2}}
            object {cylinder {TIB,TIC,TIR2}}
            object {cylinder {TIC,TID,TIR2}}
            object {cylinder {TID,TIE,TIR2}}
            object {cylinder {TIE,TIA,TIR2}}
            object {cylinder {TIE,TIB,TIR2}}
            object {sphere {TIA,TIR2}}
            object {sphere {TIB,TIR2}}
            object {sphere {TIC,TIR2}}
            object {sphere {TID,TIR2}}
            object {sphere {TIE,TIR2}}
          }
          scale <5,1,1>
        }
        object {box {<-0.05, -1, -2>, <0.05, 3, 4>}}
      }
      texture {TI_Tex2}
    }
    object {
      mesh {
        triangle {TIA,TIB,TIE}
        triangle {TIC,TIB,TIE}
        triangle {TIC,TID,TIE}
      }
      texture {TI_SolarPanel}
    }
  }
  rotate <0,0,40>
  translate <0,1,0>
}
#declare TI_PanelCentre = object {
  union {
    object {
      intersection {
        object {cone {<0,-0.001,0>, 0.3, <0,0.0501,0>, 0.25} scale <1,1,100> rotate <0,25,0>}
        object {cone {<0,-0.001,0>, 0.3, <0,0.0501,0>, 0.25} scale <1,1,100> rotate <0,-25,0>}
        object {cone {<0,0,0>, 0.2, <0,0.05,0>, 0.15} scale <100,1,2> rotate <0,0,0>}
      }
      texture {TI_Tex2}
    }
    object {
      intersection {
        object {cone {<0,-0.001,0>, 0.25, <0,0.0501,0>, 0.2} scale <0.5,0.2,50> rotate <0,25,0>}
        object {cone {<0,-0.001,0>, 0.25, <0,0.0501,0>, 0.2} scale <0.5,0.2,50> rotate <0,-25,0>}
        object {cone {<0,0,0>, 0.2, <0,0.05,0>, 0.15} scale <50,0.2,1> rotate <0,0,0>}
      }
      translate <0,0.05,0>
      texture {TI_Tex3}
    }
    object {cylinder {<0,0,0>, <0,0.08,0>, 0.1} texture {TI_Tex2}}
    object {cone {<0,0.08,0>, 0.1, <0,0.1, 0>, 0.05} texture {TI_Tex2}}
  }
}

#declare TI_PanelB = object {
  union {
    object {box {<-0.005, -1, -1.6>, <0.005, 1, 0>} texture {TI_SolarPanel}} // Main Section
    object {box {<0, -0.125, 0>, <0.045, 0.125, 0.8>} texture {TI_Tex2}} // Main Section

    object {box {<-0.01, -1, 0>, <0.01, 1, 0.8>} texture {TI_Tex2}}
    object {box {<-0.025, -1, (-1.6-0.05)>, <0.025, 1, (-1.6+0.05)>} texture {TI_Tex1}}
    object {box {<-0.05, -1, (-1.6-0.025)>, <0.05, 1, (-1.6+0.025)>} texture {TI_Tex2}}
    object {box {<-0.01, -1, -0.025>, <0.01, 1, 0.025>} texture {TI_Tex1}}
    object {box {<-0.025, -1, -0.01>, <0.025, 1, 0.01>} texture {TI_Tex2}}
    object {box {<0,-0.75, -0.1>, <0.025, 0.75, 0.1>} texture {TI_Tex2}}
    object {TI_PanelCentre rotate <0,0,-90> scale <1,1.25,1.75>} //Outer detail
    object {TI_PanelCentre rotate <0,0,90> scale <1,1.5,1.5>} //Inner detail

    object {
      union {
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,0.8,0>}
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,0.7,0>}
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,0.6,0>}
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,-0.6,0>}
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,-0.7,0>}
        object {box {<0,-0.02, 0.6>, <0.025,0.02, 0.8>} translate <0,-0.8,0>}
      }
      texture {TI_Tex3}
    }
    object {
      difference {
        object {box {<-0.075, -0.15, 0.6>, <0.075, 0.15, 0.9>}}
        object {cylinder {<-0.1, 0, 0>, <0.1, 0, 0>, 0.2} scale <1,1,0.25> translate <0,0,0.9>}
      }
      texture {TI_Tex2}
    }
    #declare TI_Sensor = object {
      difference {
        object {cylinder {<0,0.08,0.5>, <0,0.08,0.95>, 0.05}}
        object {cylinder {<0,0.08,0.5>, <0,0.08,1.1>, 0.03}}
      }
      texture {TI_Tex2}
    }
    object {TI_Sensor}
    object {TI_Sensor scale <1,-1,1>}
  }
}

#declare TI_Panel = object {
  union {
    object {TI_PanelA}
    object {TI_PanelA scale <1,-1,1>}
    object {TI_PanelB}
    object {TI_PanelMount}
  }
}
#declare TI_Screen = object {
  difference {
    object {cone {<0,0,1.036>, 0.7, <0,0,1.2>, 0.3}}
    object {cone {<0,0,1.036>, 0.69, <0,0,1.19>, 0.29}}
  }
  texture {TI_Screen_Tex}
}

#declare TI_ScreenFrame = object {
  union {
    object {
      intersection {
        object {torus {0.7,0.05} rotate <90,0,0> translate <0,0,1.036>}
        object {sphere {<0,0,0>, 1.251}}
      }
    }
    object {torus {0.3,0.015} rotate <90,0,0> translate <0,0,1.2>}
    #declare Count = 0
    #while (Count < 360)
    object {
      cylinder {<0,0.7,1.036>, <0,0.3,1.2>, 0.015}
      rotate <0,0,Count>
    }
    #declare Count = Count + (360/8)
    #end
  }
  texture {TI_Tex4}
}

#declare Cannon = object {
  union {
    object {cylinder {<0,0,0>, <0,0,0.4>, 0.05} texture {TI_Tex3}}
    object {cylinder {<0,0,0>, <0,0,0.5>, 0.04} texture {TI_Tex3}}
    object {
      difference {
        object {cylinder {<0,0,0>, <0,0,0.65>, 0.035} texture {TI_Tex2}}
        object {cylinder {<0,0,0.5>, <0,0,0.66>, 0.03} texture {TI_Tex3}}
      }
    }
  }
}

#declare TI_Cockpit = object {
  union {
    object { //Main cockpit shape
      difference {
        object {sphere {<0,0,0>, 1.25}}
        object {sphere {<0,0,0>, 1.15}}
        object {cylinder {<0,0,0>, <0,0,2>, 0.7}}
        object {plane {<0,-1,0>, -1}} //Top cut-off for exit hatch
        object {cylinder {<0,0,-0.81>, <0,0,-1.4>, 0.55} texture {pigment {colour rgb 0.15}}}
        object {cylinder {<-0.25, -1, 0.5>, <-0.25, -1, 1>, 0.075}}
        object {cylinder {<0.25, -1, 0.5>, <0.25, -1, 1>, 0.075}}
        object { // Cutaways for laser cannon mounting
          intersection {
            object {
              union {
                object {cylinder {<-0.25, 0, 0.5>, <-0.25, 0, 1>, 0.075}}
                object {cylinder {<0.25, 0, 0.5>, <0.25, 0, 1>, 0.075}}
              }
            }
            object {plane {<0,1,0>, 0}}
          }
          scale <1,3,1>
          translate <0,-1,0>
        }
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TI_Tex2} //pigment {colour rgb <1,0,0>}}
          texture {TI_Tex3} //pigment {colour rgb 0.7}}
        }
        translate <-0.5, -0.5, 0>
        scale 2.5
      }
    }
    object {Cannon translate <-0.25,-1.025,0.5> scale <1,1,1>}
    object {Cannon translate <-0.25,-1.025,0.5> scale <-1,1,1>}
    object { // Rear end
      difference {
        object {cone {<0,0,-0.8>, 0.85, <0,0,-1.3>, 0.6}}
        object {cylinder {<0,0,-1.15>, <0,0,-1.4>, 0.5} texture {pigment {colour rgb 0.15}}}
      }
      texture {TI_Tex2}
    }
    object { //Detail on top of rear end
      union {
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,-45>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,15>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,25>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,35>}
        object {cylinder {<0,0.85,-0.8>, <0,0.6,-1.3>, 0.01} rotate <0,0,45>}
      }
      texture {pigment {colour rgb 0.25}}
    }
    object {
      difference {
        object {
          union {
            object {cylinder {<0,0,-1>, <0,0,-1.3>, 0.3}}
            #declare Count = 0
            #while (Count < 360)
            object {
              box {<-0.025,-0.6,-1.3>, <0.025, 0.6, -1>}
               rotate <0,0,Count>
            }
            #declare Count = Count + 30
            #end
          }
        }
        object {cylinder {<0,0,-1.15>, <0,0,-2>, 0.15} texture {pigment {colour rgb 0.15}}}
      }
      texture {TI_Tex2}
    }
    object {
      intersection {
        object {box {<-1.2, -0.15, -1.1>, <1.2, 0.15, 0>}}
        object {sphere {<0,0,0>, 1.4}}
      }
      texture {pigment {colour rgb 0.15}}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.225}}
        object {plane {<0,1,0>, 1.025}}
      }
      texture {TI_Tex2}
    }
    object {
      difference {
        object {sphere {<0,0.01,0>, 1.25}}
        object {plane {<0,1,0>, 1.025}}
        object {box {<-0.4, 1.1, -2>, <-0.2, 1.5, 0.2>}}
        object {box {<0.4, 1.1, -2>, <0.2, 1.5, 0.2>}}
        object {box {<-0.9, 1.1, -2>, <-0.45, 1.5, 0>}}
        object {box {<0.9, 1.1, -2>, <0.45, 1.5, 0>}}
      }
      texture {
        material_map {
          tga "tcpmap.tga" once
          texture {TI_Tex2}
          texture {TI_Tex3}
        }
        translate <-0.5, -0.5, 0>
        rotate <90,0,0>
        scale 2.05
      }
    }
    object {
      cylinder {<0,1,0>, <0,1.025,0>, 0.75}
      texture {
        pigment {colour rgb 0.15}
      }
    }
    object {
      intersection {
        object {sphere {<0,0,0>, 1.35} scale <1.1, 0.75, 0.75>}
        object {cylinder {<-5,0,0>, <5,0,0>, 0.4}}
        object {sphere {<0,0,0>, 1.15} inverse}

      }
      texture {TI_Tex3}
    }
    object {TI_Screen}
    object {TI_ScreenFrame}
  }
}


#declare TieInterceptor = object {
  union {
    object {TI_Panel translate <3,0,0> scale <1,1,1>}
    object {TI_Panel translate <3,0,0> scale <-1,1,1>}
    object {TI_Cockpit}
  }
  scale 0.7
}

